#[non_exhaustive]pub enum Error {
MissingApiKey,
InvalidApiKey,
RateLimited {
retry_after: Option<Duration>,
},
Api {
status: u16,
cause: String,
},
Http(Error),
Decode(Error),
}Expand description
Errors returned by the Hypixel SDK.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingApiKey
A method requiring authentication was called without an API key configured.
InvalidApiKey
The configured API key was rejected by the API (HTTP 403).
RateLimited
The request was rate limited (HTTP 429).
Fields
Api
The API responded with a non-success status and an error cause.
Fields
Http(Error)
The request could not be sent or the connection failed.
Decode(Error)
The response body could not be deserialized into the expected type.