pub fn cumulative_from_levels(levels: &[SkillLevel]) -> Vec<f64>Expand description
Build a sorted cumulative threshold table from a skill’s level definitions.
pub fn cumulative_from_levels(levels: &[SkillLevel]) -> Vec<f64>Build a sorted cumulative threshold table from a skill’s level definitions.