pub struct LevelProgress {
pub level: u32,
pub total_xp: f64,
pub xp_into_level: f64,
pub xp_to_next: Option<f64>,
pub fractional_level: f64,
}Expand description
The resolved level and in-level progress for a given amount of experience.
Fields
level: u32The whole level reached.
total_xp: f64Total experience supplied.
xp_into_level: f64Experience accumulated past the start of the current level.
xp_to_next: Option<f64>Experience required to advance from the current level to the next, if any.
fractional_level: f64The level expressed as a fraction (e.g. 12.5 is halfway through level 12).