pub struct BazaarSpread {
pub buy_order_price: f64,
pub sell_order_price: f64,
}Expand description
A concise view of a single bazaar product’s order book.
Fields
buy_order_price: f64Highest price a buy order is currently offering (instant-sell price).
sell_order_price: f64Lowest price a sell order is currently asking (instant-buy price).
Implementations